@@ -1,9 +1,7 @@
 from __future__ import annotations
 
-from typing import Optional
 
 from python_search.configuration.loader import ConfigurationLoader
-from python_search.core_entities.core_entities import Key, Entry
 from python_search.entry_capture.filesystem_entry_inserter import (
     FilesystemEntryInserter,
 )
@@ -25,6 +23,30 @@ class RegisterNew:
         self.configuration = configuration
         self.entry_inserter = FilesystemEntryInserter(configuration)
 
+    def launch_ui(self):
+        from python_search.declarative_ui import UIBuilder
+        from python_search.apps.clipboard import Clipboard
+
+        clipboard_content = Clipboard().get_content()
+        default_type = "snippet"
+        if clipboard_content.startswith("http"):
+            default_type = "url"
+        result = UIBuilder().build(
+            [
+                {"key": "key", "type": "input"},
+                {"key": "value", "type": "text", "value": clipboard_content},
+                {
+                    "key": "type",
+                    "type": "select",
+                    "value": default_type,
+                    "values": ["snippet", "cli_cmd", "cmd", "url", "file"],
+                },
+            ],
+            title="Register New Entry",
+        )
+
+        self.register(key=result["key"], value=result["value"], type=result["type"])
+
     @notify_exception()
     def register(self, *, key: str, value: str, type: str):
         """
