@@ -1,4 +1,3 @@
-
 def get_page_title(url):
     from bs4 import BeautifulSoup
     import requests
@@ -6,7 +5,7 @@ def get_page_title(url):
     try:
         response = requests.get(url)
         response.raise_for_status()
-        soup = BeautifulSoup(response.text, 'html.parser')
+        soup = BeautifulSoup(response.text, "html.parser")
         return soup.title.string
     except Exception:
         return ""
@@ -15,4 +14,4 @@ def get_page_title(url):
 if __name__ == "__main__":
     import fire
 
-    fire.Fire()
\ No newline at end of file
+    fire.Fire()
